===========
NiTime Home
===========

:mod:`Nitime` is a library for time-series analysis of data from neuroscience
experiments.

It contains a core of numerical algorithms for time-series analysis both in the
time and spectral domains, a set of container objects to represent time-series,
and auxiliary objects that expose a high level interface to the numerical
machinery and make common analysis tasks easy to express with compact and
semantically clear code.

.. toctree::
   :hidden:

   documentation
   news